@@ -57,6 +57,7 @@ class Maitai:
         openai_api_key: Optional[str] = None,
         groq_api_key: Optional[str] = None,
         anthropic_api_key: Optional[str] = None,
+        cerebras_api_key: Optional[str] = None,
         organization: Optional[str] = None,
         project: Optional[str] = None,
         base_url: Union[str, httpx.URL, None] = None,
@@ -78,12 +79,16 @@ class Maitai:
                 groq_api_key = api_key
             if not anthropic_api_key:
                 anthropic_api_key = api_key
+            if not cerebras_api_key:
+                cerebras_api_key = api_key
         if openai_api_key:
             config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
             config.auth_keys.groq_api_key.key_value = groq_api_key
         if anthropic_api_key:
             config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
+        if cerebras_api_key:
+            config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
         self._client = None
         if api_key or openai_api_key or os.environ.get("OPENAI_API_KEY"):
             self._client = openai.OpenAI(
@@ -313,6 +318,7 @@ class Completions:
                 auth_keys=config.auth_keys,
                 metadata=metadata,
                 safe_mode=safe_mode,
+                extra_headers=extra_headers or {},
             )
             if self._client_params is not None:
                 chat_request.client_params = self._client_params
