@@ -8,7 +8,6 @@ import httpx
 import openai
 import openai.types as openai_types
 import openai.types.chat as openai_chat_types
-from openai.types.chat import ChatCompletionStreamOptionsParam
 
 import maitai
 from maitai._config import config
@@ -58,6 +57,7 @@ class MaitaiAsync:
         openai_api_key: Optional[str] = None,
         groq_api_key: Optional[str] = None,
         anthropic_api_key: Optional[str] = None,
+        cerebras_api_key: Optional[str] = None,
         organization: Optional[str] = None,
         project: Optional[str] = None,
         base_url: Union[str, httpx.URL, None] = None,
@@ -77,12 +77,16 @@ class MaitaiAsync:
                 groq_api_key = api_key
             if not anthropic_api_key:
                 anthropic_api_key = api_key
+            if not cerebras_api_key:
+                cerebras_api_key = api_key
         if openai_api_key:
             config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
             config.auth_keys.groq_api_key.key_value = groq_api_key
         if anthropic_api_key:
             config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
+        if cerebras_api_key:
+            config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
         self._client = None
         if api_key or openai_api_key or os.environ.get("OPENAI_API_KEY"):
             self._client = openai.AsyncClient(
@@ -264,8 +268,6 @@ class AsyncCompletions:
             presence_penalty = maitai_config.presence_penalty
         if timeout == openai.NOT_GIVEN and maitai_config.timeout > 0:
             timeout = maitai_config.timeout
-        if stream_options == openai.NOT_GIVEN and stream:
-            stream_options = ChatCompletionStreamOptionsParam(include_usage=True)
         if context_retrieval_enabled is None:
             context_retrieval_enabled = maitai_config.context_retrieval_enabled
         if fallback_model is None and maitai_config.fallback_model:
@@ -313,6 +315,7 @@ class AsyncCompletions:
                 auth_keys=config.auth_keys,
                 metadata=metadata,
                 safe_mode=safe_mode,
+                extra_headers=extra_headers or {},
             )
             if self._client_params is not None:
                 chat_request.client_params = self._client_params
@@ -328,7 +331,15 @@ class AsyncCompletions:
                     retry_args["model"] = model
                     retry_args["fallback_model"] = fallback_model
                     return _process_inference_stream_async(
-                        response, retry_args, self.create, timing
+                        response,
+                        retry_args,
+                        self.create,
+                        timing,
+                        includes_usage=(
+                            stream_options.get("include_usage", False)
+                            if stream_options and stream_options != openai.NOT_GIVEN
+                            else False
+                        ),
                     )
                 # ChatCompletion only
                 async for resp in response:
@@ -505,6 +516,7 @@ async def _process_inference_stream_async(
     retry_args: dict,
     retry_func,
     timing: RequestTimingMetric,
+    includes_usage: bool = False,
 ) -> AsyncIterable[MaitaiChunk]:
     first = True
     try:
@@ -525,6 +537,12 @@ async def _process_inference_stream_async(
                     maitai.Inference.store_request_timing_data(timing)
                 if chunk.usage:
                     return
+                if (
+                    not includes_usage
+                    and chunk.choices
+                    and chunk.choices[0].finish_reason
+                ):
+                    return
     except MaitaiConnectionError as e:
         if "gpt" not in retry_args.get("model", "") and "gpt" in retry_args.get(
             "fallback_model", ""
